@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2008, 2011 Institute for Software, HSR Hochschule fuer Technik  
+ * Copyright (c) 2008, 2014 Institute for Software, HSR Hochschule fuer Technik  
  * Rapperswil, University of applied sciences and others
  * All rights reserved. This program and the accompanying materials 
  * are made available under the terms of the Eclipse Public License v1.0 
@@ -32,7 +32,9 @@ public class InsertBeforeTestSuite {
 		suite.addTest(AddDeclarationBugTest.suite());
 		suite.addTest(MultilineWhitespaceHandlingTest.suite());
 		suite.addTest(SelfInsertionTest.suite());
-				
+		suite.addTest(InsertStatementTest.suite());
+		suite.addTest(InsertMultipleStatementsTest.suite());
+
 		return suite;
 	}
 }
