@@ -793,7 +793,6 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 	protected static void assertSameType(IType first, IType second){
 		assertNotNull(first);
 		assertNotNull(second);
-		assertTrue("Expected types to be the same, but first was: '" + first.toString() +
-				"' and second was: '" + second + "'", first.isSameType(second));
+		assertTrue("Expected types to be the same, but first was: '" + first.toString() + "' and second was: '" + second + "'", first.isSameType(second));
 	}
 }
