@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2006, 2011 IBM Corporation and others.
+ * Copyright (c) 2006, 2014 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -25,10 +25,12 @@ import org.eclipse.cdt.core.dom.ast.IASTProblem;
 import org.eclipse.cdt.core.dom.ast.IASTProblemTypeId;
 import org.eclipse.cdt.core.dom.ast.IASTReturnStatement;
 import org.eclipse.cdt.core.dom.ast.IASTStatement;
+import org.eclipse.cdt.core.dom.ast.IASTToken;
 import org.eclipse.cdt.core.dom.ast.IASTTypeId;
 import org.eclipse.cdt.core.dom.ast.INodeFactory;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTCompositeTypeSpecifier.ICPPASTBaseSpecifier;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPUnaryTypeTransformation.Operator;
+import org.eclipse.cdt.core.dom.parser.cpp.ICPPASTAttributeSpecifier;
 import org.eclipse.cdt.core.parser.IScanner;
 
 /**
@@ -53,8 +55,24 @@ public interface ICPPNodeFactory extends INodeFactory {
 	 */
 	public ICPPASTArraySubscriptExpression newArraySubscriptExpression(IASTExpression arrayExpr, IASTInitializerClause subscript);
 
+	/**
+	 * @since 5.7
+	 */
+	public ICPPASTAttribute newAttribute(char[] name, char[] scope, IASTToken argumentClause, boolean packExpansion);
+
+	/**
+	 * @since 5.7
+	 */
+	public ICPPASTAttributeSpecifier newAttributeSpecifier();
+
+	@Deprecated
 	public ICPPASTBaseSpecifier newBaseSpecifier(IASTName name, int visibility, boolean isVirtual);
 	
+	/**
+	 * @since 5.8
+	 */
+	public ICPPASTBaseSpecifier newBaseSpecifier(ICPPASTNameSpecifier nameSpecifier, int visibility, boolean isVirtual);
+	
 	@Override
 	public ICPPASTBinaryExpression newBinaryExpression(int op, IASTExpression expr1, IASTExpression expr2);
 	
@@ -78,6 +96,11 @@ public interface ICPPNodeFactory extends INodeFactory {
 	
 	public ICPPASTCatchHandler newCatchHandler(IASTDeclaration decl, IASTStatement body);
 
+	/**
+	 * @since 5.7
+	 */
+	public ICPPASTClassVirtSpecifier newClassVirtSpecifier(ICPPASTClassVirtSpecifier.SpecifierKind kind);
+	
 	@Override
 	public ICPPASTCompositeTypeSpecifier newCompositeTypeSpecifier(int key, IASTName name);
 	
@@ -242,9 +265,19 @@ public interface ICPPNodeFactory extends INodeFactory {
 	public org.eclipse.cdt.core.dom.ast.gnu.cpp.IGPPASTPointerToMember newPointerToMemberGPP(IASTName name);
 	
 	public IASTProblemTypeId newProblemTypeId(IASTProblem problem);
-	
+
+	/**
+	 * Creates a {@link ICPPASTQualifiedName}.
+	 * @since 5.7
+	 */
+	public ICPPASTQualifiedName newQualifiedName(ICPPASTName name);
+
+	/**
+	 * @deprecated Replaced by {@link #newQualifiedName(ICPPASTName)}.
+	 */
+	@Deprecated
 	public ICPPASTQualifiedName newQualifiedName();
-	
+
 	/**
 	 * Creates a range based for statement.
 	 * @since 5.3
@@ -358,6 +391,11 @@ public interface ICPPNodeFactory extends INodeFactory {
 
 	public ICPPASTUsingDirective newUsingDirective(IASTName name);
 
+	/**
+	 * @since 5.7
+	 */
+	public ICPPASTVirtSpecifier newVirtSpecifier(ICPPASTVirtSpecifier.SpecifierKind kind);
+	
 	public ICPPASTVisibilityLabel newVisibilityLabel(int visibility);
 	
 	public ICPPASTWhileStatement newWhileStatement();
