@@ -12,6 +12,7 @@
  *     Mike Kucera (IBM) - bug #206952
  *     Sergey Prigogin (Google)
  *     Thomas Corbat (IFS)
+ *     Anders Dahlberg (Ericsson) - bug 84144
  *******************************************************************************/
 package org.eclipse.cdt.internal.core.dom.parser.c;
 
@@ -594,6 +595,8 @@ public class GNUCSourceParser extends AbstractGNUSourceCodeParser {
             return unaryExpression(IASTUnaryExpression.op_star, ctx, strat);
         case IToken.tAMPER:
             return unaryExpression(IASTUnaryExpression.op_amper, ctx, strat);
+        case IToken.tAND:
+            return unaryExpression(IASTUnaryExpression.op_labelReference, ctx, strat);
         case IToken.tPLUS:
             return unaryExpression(IASTUnaryExpression.op_plus, ctx, strat);
         case IToken.tMINUS:
