@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004, 2010 IBM Corporation and others.
+ * Copyright (c) 2004, 2014 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -27,6 +27,7 @@ import org.eclipse.cdt.core.dom.ast.IType;
 import org.eclipse.cdt.core.dom.ast.ITypedef;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTCompositeTypeSpecifier;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTElaboratedTypeSpecifier;
+import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTNameSpecifier;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTQualifiedName;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPBase;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPBlockScope;
@@ -54,6 +55,9 @@ public class CPPClassType extends PlatformObject implements ICPPInternalClassTyp
 		public CPPClassTypeProblem(IASTName name, int id) {
 			super(name, id);
 		}
+		public CPPClassTypeProblem(ICPPASTNameSpecifier nameSpec, int id) {
+			super(nameSpec, id, nameSpec instanceof IASTName ? null : nameSpec.toCharArray());
+		}
 		public CPPClassTypeProblem(IASTNode node, int id, char[] arg) {
 			super(node, id, arg);
 		}
@@ -119,6 +123,7 @@ public class CPPClassType extends PlatformObject implements ICPPInternalClassTyp
 	private IASTName[] declarations;
 	private boolean checked;
 	private ICPPClassType typeInIndex;
+	private ICPPBase[] bases;
 
 	public CPPClassType(IASTName name, IBinding indexBinding) {
 		name = stripQualifier(name);
@@ -168,7 +173,7 @@ public class CPPClassType extends PlatformObject implements ICPPInternalClassTyp
 			while (node instanceof IASTName)
 				node = node.getParent();
 			if (node instanceof ICPPASTCompositeTypeSpecifier)
-				return (ICPPASTCompositeTypeSpecifier)node;
+				return (ICPPASTCompositeTypeSpecifier) node;
 		}
 		return null;
 	}
@@ -311,7 +316,10 @@ public class CPPClassType extends PlatformObject implements ICPPInternalClassTyp
 	
 	@Override
 	public ICPPBase[] getBases() {
-		return ClassTypeHelper.getBases(this);
+		if (bases == null) {
+			bases = ClassTypeHelper.getBases(this);
+		}
+		return bases;
 	}
 
 	@Override
