@@ -126,6 +126,11 @@ public class EvalUnaryTypeID extends CPPDependentEvaluation {
 		return false;
 	}
 
+	@Override
+	public boolean isConstantExpression(IASTNode point) {
+		return true;
+	}
+
 	@Override
 	public IType getTypeOrFunctionSet(IASTNode point) {
 		if (fType == null)
@@ -215,7 +220,7 @@ public class EvalUnaryTypeID extends CPPDependentEvaluation {
 
 	@Override
 	public ICPPEvaluation computeForFunctionCall(CPPFunctionParameterMap parameterMap,
-			int maxdepth, IASTNode point) {
+			ConstexprEvaluationContext context) {
 		return this;
 	}
 
