@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2008, 2012 Institute for Software, HSR Hochschule fuer Technik  
+ * Copyright (c) 2008, 2014 Institute for Software, HSR Hochschule fuer Technik  
  * Rapperswil, University of applied sciences and others
  * All rights reserved. This program and the accompanying materials 
  * are made available under the terms of the Eclipse Public License v1.0 
@@ -14,6 +14,8 @@
  *******************************************************************************/
 package org.eclipse.cdt.internal.core.dom.rewrite.astwriter;
 
+import java.util.EnumSet;
+
 import org.eclipse.cdt.core.dom.ast.IASTArrayDeclarator;
 import org.eclipse.cdt.core.dom.ast.IASTArrayModifier;
 import org.eclipse.cdt.core.dom.ast.IASTDeclaration;
@@ -65,7 +67,7 @@ public class DeclaratorWriter extends NodeWriter {
 		}
 
 		visitor.setSpaceNeededBeforeName(false);
-		writeTrailingComments(declarator, false);			
+		writeTrailingComments(declarator, false);
 	}
 
 	protected void writeDefaultDeclarator(IASTDeclarator declarator) {
@@ -74,6 +76,7 @@ public class DeclaratorWriter extends NodeWriter {
 		IASTName name = declarator.getName();
 		name.accept(visitor);
 		writeNestedDeclarator(declarator);
+		writeAttributes(declarator, EnumSet.of(SpaceLocation.BEFORE));
 		IASTInitializer init = getInitializer(declarator);
 		if (init != null) {
 			init.accept(visitor);
@@ -82,7 +85,9 @@ public class DeclaratorWriter extends NodeWriter {
 
 	protected void writePointerOperators(IASTDeclarator declarator, IASTPointerOperator[] pointOps) {
 		for (IASTPointerOperator operator : pointOps) {
+			writeGCCAttributes(operator, EnumSet.noneOf(SpaceLocation.class));
 			writePointerOperator(operator);
+			writeCPPAttributes(operator, EnumSet.noneOf(SpaceLocation.class));
 		}
 	}
 
@@ -153,6 +158,7 @@ public class DeclaratorWriter extends NodeWriter {
 			scribe.print(PURE_VIRTUAL);
 		}
 		writeExceptionSpecification(funcDec, funcDec.getExceptionSpecification(), funcDec.getNoexceptExpression());
+		writeAttributes(funcDec, EnumSet.of(SpaceLocation.BEFORE));
 		if (funcDec.getTrailingReturnType() != null) {
 			scribe.printSpace();
 			scribe.print(ARROW_OPERATOR);
@@ -260,6 +266,7 @@ public class DeclaratorWriter extends NodeWriter {
 			ex.accept(visitor);
 		}
 		scribe.print(']');
+		writeAttributes(modifier, EnumSet.noneOf(SpaceLocation.class));
 	}
 
 	private void writeFieldDeclarator(IASTFieldDeclarator fieldDecl) {
