@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2011 QNX Software Systems and others.
+ * Copyright (c) 2007, 2014 QNX Software Systems and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -264,7 +264,7 @@ public class PDOMCPPClassTemplate extends PDOMCPPClassType
 		if (nchars == null || !CharArrayUtils.equals(nchars, getNameCharArray()))
 			return false;
 
-		return SemanticUtil.isSameOwner(getOwner(), ctype.getOwner());
+		return SemanticUtil.haveSameOwner(this, ctype);
 	}
 
 	@Override
