@@ -648,7 +648,7 @@ class PDOMCPPLinkage extends PDOMLinkage implements IIndexCPPBindingConstants {
 				if (type instanceof ICPPClassType) {
 					ArrayUtil.addAll(old, ClassTypeHelper.getImplicitMethods((ICPPClassType) type, point));
 				}
-				ICPPMethod[] implicit= ((ICPPClassScope) scope).getImplicitMethods();
+				ICPPMethod[] implicit= ClassTypeHelper.getImplicitMethods(scope, point);
 				for (ICPPMethod method : implicit) {
 					if (!(method instanceof IProblemBinding)) {
 						PDOMBinding pdomBinding= adaptBinding(method);
@@ -1011,17 +1011,10 @@ class PDOMCPPLinkage extends PDOMLinkage implements IIndexCPPBindingConstants {
 		if (parentNode instanceof ICPPASTQualifiedName) {
 			if (name != ((ICPPASTQualifiedName) parentNode).getLastName())
 				return;
+	    	name = (IASTName) parentNode;
 	    	parentNode = parentNode.getParent();
 		}
-		if (name.getPropertyInParent() == ICPPASTBaseSpecifier.NAME ||
-				(name.getPropertyInParent() == ICPPASTTemplateId.TEMPLATE_NAME &&
-				parentNode.getPropertyInParent() == ICPPASTBaseSpecifier.NAME)) {
-			pdomName.setIsBaseSpecifier();
-		} else if (parentNode instanceof ICPPASTUsingDirective) {
-			IASTNode parent= name.getParent();
-			if (parent instanceof ICPPASTQualifiedName) {
-				name = (IASTName) parent;
-			}
+		if (parentNode instanceof ICPPASTUsingDirective) {
 			IScope container= CPPVisitor.getContainingScope(name);
 			boolean doit= false;
 			PDOMCPPNamespace containerNS= null;
@@ -1100,6 +1093,19 @@ class PDOMCPPLinkage extends PDOMLinkage implements IIndexCPPBindingConstants {
 					}
 				}
 			}
+		} else {
+			if (name.getPropertyInParent() == ICPPASTTemplateId.TEMPLATE_NAME) {
+		    	name = (IASTName) parentNode;
+		    	parentNode = parentNode.getParent();
+			}
+			if (parentNode instanceof ICPPASTQualifiedName) {
+				if (name != ((ICPPASTQualifiedName) parentNode).getLastName())
+					return;
+		    	name = (IASTName) parentNode;
+		    	parentNode = parentNode.getParent();
+			}
+			if (name.getPropertyInParent() == ICPPASTBaseSpecifier.NAME_SPECIFIER)
+				pdomName.setIsBaseSpecifier();
 		}
 	}
 
@@ -1160,12 +1166,10 @@ class PDOMCPPLinkage extends PDOMLinkage implements IIndexCPPBindingConstants {
 			}
 			if (file == null && !(binding instanceof IIndexBinding)) {
 				IBinding owner= binding.getOwner();
-				if (owner instanceof ICPPNamespace) {
-					if (owner.getNameCharArray().length == 0) {
-						IASTNode node= ASTInternal.getDeclaredInSourceFileOnly(getPDOM(), binding, false, glob);
-						if (node != null) {
-							file= wpdom.getFileForASTNode(getLinkageID(), node);
-						}
+				if (owner instanceof ICPPNamespace && owner.getNameCharArray().length == 0) {
+					IASTNode node= ASTInternal.getDeclaredInSourceFileOnly(getPDOM(), binding, false, glob);
+					if (node != null) {
+						file= wpdom.getFileForASTNode(getLinkageID(), node);
 					}
 				}
 			}
