@@ -43,11 +43,13 @@ import org.eclipse.cdt.core.dom.ast.ITypedef;
 import org.eclipse.cdt.core.dom.ast.IVariable;
 import org.eclipse.cdt.core.dom.ast.c.ICExternalBinding;
 import org.eclipse.cdt.core.dom.ast.c.ICFunctionScope;
+import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTClassVirtSpecifier;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTCompositeTypeSpecifier;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTFunctionDeclarator;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTNameSpecifier;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTQualifiedName;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTTemplateId;
+import org.eclipse.cdt.core.dom.ast.cpp.ICPPASTVirtSpecifier;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPBlockScope;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPClassType;
 import org.eclipse.cdt.core.dom.ast.cpp.ICPPFunctionScope;
@@ -62,6 +64,7 @@ import org.eclipse.cdt.core.index.IIndexName;
 import org.eclipse.cdt.core.parser.util.CharArrayUtils;
 import org.eclipse.cdt.ui.CUIPlugin;
 import org.eclipse.cdt.ui.PreferenceConstants;
+import org.eclipse.cdt.ui.text.ICColorConstants;
 import org.eclipse.cdt.ui.text.ISemanticToken;
 
 import org.eclipse.cdt.internal.core.dom.parser.cpp.ICPPUnknownBinding;
@@ -190,8 +193,7 @@ public class SemanticHighlightings {
 	 * A named preference part that controls the highlighting of operators that have been overloaded.
 	 */
 	public static final String OVERLOADED_OPERATOR= "overloadedOperator"; //$NON-NLS-1$
-
-
+	
 	/** Init debugging mode */
 	private static final boolean DEBUG= "true".equalsIgnoreCase(Platform.getDebugOption("org.eclipse.cdt.ui/debug/SemanticHighlighting"));  //$NON-NLS-1$//$NON-NLS-2$
 
@@ -203,7 +205,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for static fields.
 	 */
-	private static final class StaticFieldHighlighting extends SemanticHighlighting {
+	private static final class StaticFieldHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return STATIC_FIELD;
@@ -254,7 +256,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for fields.
 	 */
-	private static final class FieldHighlighting extends SemanticHighlighting {
+	private static final class FieldHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return FIELD;
@@ -305,7 +307,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for method declarations.
 	 */
-	private static final class MethodDeclarationHighlighting extends SemanticHighlighting {
+	private static final class MethodDeclarationHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return METHOD_DECLARATION;
@@ -382,7 +384,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for static method invocations.
 	 */
-	private static final class StaticMethodInvocationHighlighting extends SemanticHighlighting {
+	private static final class StaticMethodInvocationHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return STATIC_METHOD_INVOCATION;
@@ -436,7 +438,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for methods.
 	 */
-	private static final class MethodHighlighting extends SemanticHighlighting {
+	private static final class MethodHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return METHOD;
@@ -489,7 +491,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for function declarations.
 	 */
-	private static final class FunctionDeclarationHighlighting extends SemanticHighlighting {
+	private static final class FunctionDeclarationHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return FUNCTION_DECLARATION;
@@ -560,7 +562,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for functions.
 	 */
-	private static final class FunctionHighlighting extends SemanticHighlighting {
+	private static final class FunctionHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return FUNCTION;
@@ -613,7 +615,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for local variable declarations.
 	 */
-	private static final class LocalVariableDeclarationHighlighting extends SemanticHighlighting {
+	private static final class LocalVariableDeclarationHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return LOCAL_VARIABLE_DECLARATION;
@@ -655,13 +657,8 @@ public class SemanticHighlightings {
 							&& !(binding instanceof IField)
 							&& !(binding instanceof IParameter)
 							&& !(binding instanceof IProblemBinding)) {
-						try {
-							IScope scope= binding.getScope();
-							if (LocalVariableHighlighting.isLocalScope(scope)) {
-								return true;
-							}
-						} catch (DOMException exc) {
-							CUIPlugin.log(exc);
+						if (LocalVariableHighlighting.isLocalVariable((IVariable) binding)) {
+							return true;
 						}
 					}
 				}
@@ -673,7 +670,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for local variables.
 	 */
-	private static final class LocalVariableHighlighting extends SemanticHighlighting {
+	private static final class LocalVariableHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return LOCAL_VARIABLE;
@@ -715,13 +712,8 @@ public class SemanticHighlightings {
 							&& !(binding instanceof IField)
 							&& !(binding instanceof IParameter)
 							&& !(binding instanceof IProblemBinding)) {
-						try {
-							IScope scope= binding.getScope();
-							if (isLocalScope(scope)) {
-								return true;
-							}
-						} catch (DOMException exc) {
-							CUIPlugin.log(exc);
+						if (isLocalVariable((IVariable) binding)) {
+							return true;
 						}
 					}
 				}
@@ -729,27 +721,37 @@ public class SemanticHighlightings {
 			return false;
 		}
 
-	    public static boolean isLocalScope(IScope scope) {
-	        while (scope != null) {
-	            if (scope instanceof ICPPFunctionScope ||
-	                    scope instanceof ICPPBlockScope ||
-	                    scope instanceof ICFunctionScope) {
-	                return true;
-	            }
-	            try {
-	                scope= scope.getParent();
-	            } catch (DOMException e) {
-	                scope= null;
-	            }
-	        }
-	        return false;
+	    public static boolean isLocalVariable(IVariable variable) {
+	    	// A variable marked 'extern' declares a global
+	    	// variable even if the declaration is local.
+	    	if (variable.isExtern()) {
+	    		return false;
+	    	}
+	    	try {
+		    	IScope scope= variable.getScope();
+		        while (scope != null) {
+		            if (scope instanceof ICPPFunctionScope ||
+		                    scope instanceof ICPPBlockScope ||
+		                    scope instanceof ICFunctionScope) {
+		                return true;
+		            }
+		            try {
+		                scope= scope.getParent();
+		            } catch (DOMException e) {
+		                scope= null;
+		            }
+		        }
+	    	} catch (DOMException exc) {
+	    		CUIPlugin.log(exc);
+	    	}
+	    	return false;
 	    }
 	}
 
 	/**
 	 * Semantic highlighting for global variables.
 	 */
-	private static final class GlobalVariableHighlighting extends SemanticHighlighting {
+	private static final class GlobalVariableHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return GLOBAL_VARIABLE;
@@ -794,13 +796,8 @@ public class SemanticHighlightings {
 						&& !(binding instanceof IParameter)
 						&& !(binding instanceof ICPPTemplateNonTypeParameter)
 						&& !(binding instanceof IProblemBinding)) {
-					try {
-						IScope scope= binding.getScope();
-						if (!LocalVariableHighlighting.isLocalScope(scope)) {
-							return true;
-						}
-					} catch (DOMException exc) {
-						CUIPlugin.log(exc);
+					if (!LocalVariableHighlighting.isLocalVariable((IVariable) binding)) {
+						return true;
 					}
 				}
 			}
@@ -811,7 +808,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for parameter variables.
 	 */
-	private static final class ParameterVariableHighlighting extends SemanticHighlighting {
+	private static final class ParameterVariableHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return PARAMETER_VARIABLE;
@@ -855,7 +852,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for template parameters.
 	 */
-	private static final class TemplateParameterHighlighting extends SemanticHighlighting {
+	private static final class TemplateParameterHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return TEMPLATE_PARAMETER;
@@ -902,7 +899,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for classes.
 	 */
-	private static final class ClassHighlighting extends SemanticHighlighting {
+	private static final class ClassHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return CLASS;
@@ -952,7 +949,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for enums.
 	 */
-	private static final class EnumHighlighting extends SemanticHighlighting {
+	private static final class EnumHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return ENUM;
@@ -999,7 +996,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for macro references.
 	 */
-	private static final class MacroReferenceHighlighting extends SemanticHighlighting {
+	private static final class MacroReferenceHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return MACRO_REFERENCE;
@@ -1046,7 +1043,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for macro definitions.
 	 */
-	private static final class MacroDefinitionHighlighting extends SemanticHighlighting {
+	private static final class MacroDefinitionHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return MACRO_DEFINITION;
@@ -1093,7 +1090,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for typedefs.
 	 */
-	private static final class TypedefHighlighting extends SemanticHighlighting {
+	private static final class TypedefHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return TYPEDEF;
@@ -1144,7 +1141,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for namespaces.
 	 */
-	private static final class NamespaceHighlighting extends SemanticHighlighting {
+	private static final class NamespaceHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return NAMESPACE;
@@ -1188,7 +1185,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for labels.
 	 */
-	private static final class LabelHighlighting extends SemanticHighlighting {
+	private static final class LabelHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return LABEL;
@@ -1232,7 +1229,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for enumerators.
 	 */
-	private static final class EnumeratorHighlighting extends SemanticHighlighting {
+	private static final class EnumeratorHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return ENUMERATOR;
@@ -1283,7 +1280,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for problems.
 	 */
-	private static final class ProblemHighlighting extends SemanticHighlighting {
+	private static final class ProblemHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return PROBLEM;
@@ -1345,7 +1342,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for external SDK references.
 	 */
-	private static final class ExternalSDKHighlighting extends SemanticHighlighting {
+	private static final class ExternalSDKHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return EXTERNAL_SDK;
@@ -1434,7 +1431,7 @@ public class SemanticHighlightings {
 	/**
 	 * Semantic highlighting for functions.
 	 */
-	private static final class OverloadedOperatorHighlighting extends SemanticHighlighting {
+	private static final class OverloadedOperatorHighlighting extends SemanticHighlightingWithOwnPreference {
 		@Override
 		public String getPreferenceKey() {
 			return OVERLOADED_OPERATOR;
@@ -1496,7 +1493,55 @@ public class SemanticHighlightings {
 			return false;
 		}
 	}
+	
+	/**
+	 * Semantic highlighting for context-sensitive keywords.
+	 * 
+	 * This does not get its own color and style; rather, it uses
+	 * the color and style of the 'Keyword' syntactic highlighting.
+	 */
+	private static final class ContextSensitiveKeywordHighlighting extends SemanticHighlighting {
+		@Override
+		public String getPreferenceKey() {
+			return ICColorConstants.C_KEYWORD;
+		}
+		
+		@Override
+		public boolean isEnabledByDefault() {
+			return true;
+		}
 
+		@Override
+		public boolean requiresImplicitNames() {
+			return false;
+		}
+
+		@Override
+		public boolean consumes(ISemanticToken token) {
+			// Currently the only context-sensitive keywords are the
+			// 'final' and 'override' virt-specifiers at the end of a
+			// method declaration, and the 'final' class-virt-specifier
+			// after a class name.
+			return token.getNode() instanceof ICPPASTVirtSpecifier
+					|| token.getNode() instanceof ICPPASTClassVirtSpecifier;
+		}
+	}
+
+	// Note on the get___PreferenceKey() functions below:
+	//  - For semantic highlightings deriving from SemanticHighlightingWithOwnPreference,
+	//    these functions return keys for accessing the highlighting's own preferences.
+	//  - For semantic highlightings not deriving from SemanticHighlightingWithOwnPreference,
+	//    their getPreferenceKey() returns the preference key for a corresponding syntactic
+	//    highlighting, and these functions build preference keys for specific preferences
+	//    (e.g. color) based on that.
+	//  - getEnabledPreferenceKey() is special in that there is no corresponding preference
+	//    for synactic highlightings (they are always enabled), but we need to allow all
+	//    semantic highlightings to be disabled for testing purposes, so we build a preference
+	//    key using the naming scheme for semantic preferences for all semantic highlightings.
+	//    From a user's perspective, semantic highlightings not deriving from
+	//    SemanticHighlightingWithOwnPreference are still always enabled because there is no
+	//    way to disable them in the UI.
+	
 	/**
 	 * A named preference that controls the given semantic highlighting's color.
 	 *
@@ -1504,7 +1549,11 @@ public class SemanticHighlightings {
 	 * @return the color preference key
 	 */
 	public static String getColorPreferenceKey(SemanticHighlighting semanticHighlighting) {
-		return PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_PREFIX + semanticHighlighting.getPreferenceKey() + PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_COLOR_SUFFIX;
+		if (semanticHighlighting instanceof SemanticHighlightingWithOwnPreference) {
+			return PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_PREFIX + semanticHighlighting.getPreferenceKey() + PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_COLOR_SUFFIX;
+		} else {
+			return semanticHighlighting.getPreferenceKey();
+		}
 	}
 
 	/**
@@ -1514,7 +1563,11 @@ public class SemanticHighlightings {
 	 * @return the bold preference key
 	 */
 	public static String getBoldPreferenceKey(SemanticHighlighting semanticHighlighting) {
-		return PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_PREFIX + semanticHighlighting.getPreferenceKey() + PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_BOLD_SUFFIX;
+		if (semanticHighlighting instanceof SemanticHighlightingWithOwnPreference) {
+			return PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_PREFIX + semanticHighlighting.getPreferenceKey() + PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_BOLD_SUFFIX;
+		} else {
+			return semanticHighlighting.getPreferenceKey() + PreferenceConstants.EDITOR_BOLD_SUFFIX;
+		}
 	}
 
 	/**
@@ -1524,7 +1577,11 @@ public class SemanticHighlightings {
 	 * @return the italic preference key
 	 */
 	public static String getItalicPreferenceKey(SemanticHighlighting semanticHighlighting) {
-		return PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_PREFIX + semanticHighlighting.getPreferenceKey() + PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_ITALIC_SUFFIX;
+		if (semanticHighlighting instanceof SemanticHighlightingWithOwnPreference) {
+			return PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_PREFIX + semanticHighlighting.getPreferenceKey() + PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_ITALIC_SUFFIX;
+		} else {
+			return semanticHighlighting.getPreferenceKey() + PreferenceConstants.EDITOR_ITALIC_SUFFIX;
+		}
 	}
 
 	/**
@@ -1534,7 +1591,11 @@ public class SemanticHighlightings {
 	 * @return the strikethrough preference key
 	 */
 	public static String getStrikethroughPreferenceKey(SemanticHighlighting semanticHighlighting) {
-		return PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_PREFIX + semanticHighlighting.getPreferenceKey() + PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_STRIKETHROUGH_SUFFIX;
+		if (semanticHighlighting instanceof SemanticHighlightingWithOwnPreference) {			
+			return PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_PREFIX + semanticHighlighting.getPreferenceKey() + PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_STRIKETHROUGH_SUFFIX;
+		} else {
+			return semanticHighlighting.getPreferenceKey() + PreferenceConstants.EDITOR_STRIKETHROUGH_SUFFIX;
+		}
 	}
 
 	/**
@@ -1544,7 +1605,11 @@ public class SemanticHighlightings {
 	 * @return the underline preference key
 	 */
 	public static String getUnderlinePreferenceKey(SemanticHighlighting semanticHighlighting) {
-		return PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_PREFIX + semanticHighlighting.getPreferenceKey() + PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_UNDERLINE_SUFFIX;
+		if (semanticHighlighting instanceof SemanticHighlightingWithOwnPreference) {
+			return PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_PREFIX + semanticHighlighting.getPreferenceKey() + PreferenceConstants.EDITOR_SEMANTIC_HIGHLIGHTING_UNDERLINE_SUFFIX;
+		} else {
+			return semanticHighlighting.getPreferenceKey() + PreferenceConstants.EDITOR_UNDERLINE_SUFFIX;
+		}
 	}
 
 	/**
@@ -1621,6 +1686,7 @@ public class SemanticHighlightings {
 		highlightings.put(new Key(210), new NamespaceHighlighting());
 		highlightings.put(new Key(220), new LabelHighlighting());
 		highlightings.put(new Key(230), new EnumeratorHighlighting());
+		highlightings.put(new Key(240), new ContextSensitiveKeywordHighlighting());
 	}
 
 	private static final String ExtensionPoint = "semanticHighlighting"; //$NON-NLS-1$
@@ -1670,11 +1736,14 @@ public class SemanticHighlightings {
 		SemanticHighlighting[] semanticHighlightings= getSemanticHighlightings();
 		for (SemanticHighlighting semanticHighlighting : semanticHighlightings) {
 			store.setDefault(SemanticHighlightings.getEnabledPreferenceKey(semanticHighlighting), DEBUG || semanticHighlighting.isEnabledByDefault());
-			PreferenceConverter.setDefault(store, SemanticHighlightings.getColorPreferenceKey(semanticHighlighting), semanticHighlighting.getDefaultTextColor());
-			store.setDefault(SemanticHighlightings.getBoldPreferenceKey(semanticHighlighting), semanticHighlighting.isBoldByDefault());
-			store.setDefault(SemanticHighlightings.getItalicPreferenceKey(semanticHighlighting), semanticHighlighting.isItalicByDefault());
-			store.setDefault(SemanticHighlightings.getStrikethroughPreferenceKey(semanticHighlighting), semanticHighlighting.isStrikethroughByDefault());
-			store.setDefault(SemanticHighlightings.getUnderlinePreferenceKey(semanticHighlighting), DEBUG || semanticHighlighting.isUnderlineByDefault());
+			if (semanticHighlighting instanceof SemanticHighlightingWithOwnPreference) {
+				SemanticHighlightingWithOwnPreference highlighting = (SemanticHighlightingWithOwnPreference) semanticHighlighting;
+				PreferenceConverter.setDefault(store, SemanticHighlightings.getColorPreferenceKey(highlighting), highlighting.getDefaultTextColor());
+				store.setDefault(SemanticHighlightings.getBoldPreferenceKey(highlighting), highlighting.isBoldByDefault());
+				store.setDefault(SemanticHighlightings.getItalicPreferenceKey(highlighting), highlighting.isItalicByDefault());
+				store.setDefault(SemanticHighlightings.getStrikethroughPreferenceKey(highlighting), highlighting.isStrikethroughByDefault());
+				store.setDefault(SemanticHighlightings.getUnderlinePreferenceKey(highlighting), DEBUG || highlighting.isUnderlineByDefault());
+			}
 		}
 	}
 
