@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2013 IBM Corporation and others.
+ * Copyright (c) 2000, 2014 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -14,6 +14,7 @@
  *     Kirk Beitz (Nokia)
  *     James Blackburn (Broadcom Corp.)
  *     Jens Elmenthaler - http://bugs.eclipse.org/173458 (camel case completion)
+ *     Thomas Corbat (IFS)
  *******************************************************************************/
 package org.eclipse.cdt.internal.ui.preferences;
 
@@ -49,6 +50,9 @@ public final class PreferencesMessages extends NLS {
 	public static String CEditorPreferencePage_ContentAssistPage_autoActivationEnableDoubleColon;
 	public static String CEditorPreferencePage_ContentAssistPage_autoActivationEnableReplaceDotWithArrow;
 	public static String CEditorPreferencePage_ContentAssistPage_autoActivationDelay;
+	public static String CEditorPreferencePage_ContentAssistPage_defaultArgumentsGroupTitle;
+	public static String CEditorPreferencePage_ContentAssistPage_displayParametersWithDefaultArgument;
+	public static String CEditorPreferencePage_ContentAssistPage_displayDefaultArguments;
 	public static String CEditorPreferencePage_ContentAssistPage_proposalFilterSelect;
 	public static String CEditorPreferencePage_ContentAssistPage_completionProposalBackgroundColor;
 	public static String CEditorPreferencePage_ContentAssistPage_completionProposalForegroundColor;
@@ -459,6 +463,7 @@ public final class PreferencesMessages extends NLS {
 	public static String IncludePragmasBlock_export_pattern;
 	public static String IncludePragmasBlock_begin_exports_pattern;
 	public static String IncludePragmasBlock_end_exports_pattern;
+	public static String IncludePragmasBlock_private_pattern;
 
 	public static String NameStylePreferencePage_title;
 	public static String NameStyleBlock_code_node;
@@ -475,6 +480,8 @@ public final class PreferencesMessages extends NLS {
 	public static String NameStyleBlock_getter_node_description;
 	public static String NameStyleBlock_setter_node;
 	public static String NameStyleBlock_setter_node_description;
+	public static String NameStyleBlock_include_guard_node;
+	public static String NameStyleBlock_include_guard_node_description;
 	public static String NameStyleBlock_cpp_source_node;
 	public static String NameStyleBlock_cpp_source_node_description;
 	public static String NameStyleBlock_cpp_header_node;
@@ -493,6 +500,9 @@ public final class PreferencesMessages extends NLS {
 	public static String NameStyleBlock_prefix_for_boolean_label;
 	public static String NameStyleBlock_suffix_label;
 	public static String NameStyleBlock_preview_label;
+	public static String NameStyleBlock_file_path_relative_to_source_folder;
+	public static String NameStyleBlock_file_name;
+	public static String NameStyleBlock_unique_identifier;
 	public static String NameStyleBlock_select_concrete_category;
 	public static String NameStyleBlock_invalid_prefix;
 	public static String NameStyleBlock_invalid_word_delimiter;
@@ -555,6 +565,7 @@ public final class PreferencesMessages extends NLS {
 	public static String ScalabilityPreferencePage_parserSettings_group_label;
 	public static String ScalabilityPreferencePage_skipTrivialExpressions_label;
 	public static String ScalabilityPreferencePage_maximumTrivialExpressions_label;
+	public static String ScalabilityPreferencePage_maximumTokensPerTU_label;
 
 	public static String IndexerStrategyBlock_activeBuildConfig;
 	public static String IndexerStrategyBlock_autoUpdate;
