@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010, 2013 TUBITAK BILGEM-ITI and others.
+ * Copyright (c) 2010, 2014 TUBITAK BILGEM-ITI and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -8,6 +8,7 @@
  * Contributors:
  *     Onur Akdemir (TUBITAK BILGEM-ITI) - Multi-process debugging (Bug 237306)
  *     Marc Khouzam (Ericsson) - Workaround for Bug 352998
+ *     Marc Khouzam (Ericsson) - Update breakpoint handling for GDB >= 7.4 (Bug 389945)
  *******************************************************************************/
 package org.eclipse.cdt.dsf.gdb.service;
 
@@ -379,7 +380,6 @@ public class GDBProcesses_7_2 extends GDBProcesses_7_1 {
 	    }
 	}
 	
-	@SuppressWarnings("unchecked")
 	private void connectToTarget(IProcessDMContext procCtx, RequestMonitor rm) {
 		ILaunch launch = (ILaunch)procCtx.getAdapter(ILaunch.class);
 		assert launch != null;
@@ -559,11 +559,14 @@ public class GDBProcesses_7_2 extends GDBProcesses_7_1 {
     @Override
     public void eventDispatched(IExitedDMEvent e) {
     	IDMContext dmc = e.getDMContext();
-    	if (dmc instanceof IContainerDMContext) {
+    	if (dmc instanceof IBreakpointsTargetDMContext) {
     		// A process has died, we should stop tracking its breakpoints, but only if it is not restarting
+    		// We only do this when the process is a breakpointTargetDMC itself (GDB < 7.4);
+    		// we don't want to stop tracking breakpoints when breakpoints are only set once
+    		// for all processes (GDB >= 7.4)
     		if (!fProcRestarting.remove(dmc)) {
     			if (fBackend.getSessionType() != SessionType.CORE) {
-    				IBreakpointsTargetDMContext bpTargetDmc = DMContexts.getAncestorOfType(dmc, IBreakpointsTargetDMContext.class);
+    				IBreakpointsTargetDMContext bpTargetDmc = (IBreakpointsTargetDMContext)dmc;
     				MIBreakpointsManager bpmService = getServicesTracker().getService(MIBreakpointsManager.class);
     				if (bpmService != null) {
     					bpmService.stopTrackingBreakpoints(bpTargetDmc, new ImmediateRequestMonitor() {
