@@ -10,13 +10,17 @@
  *     Ericsson 		  - Modified for handling of multiple execution contexts	
  *     Axel Mueller       - Bug 306555 - Add support for cast to type / view as array (IExpressions2)	
  *     Jens Elmenthaler (Verigy) - Added Full GDB pretty-printing support (bug 302121)
+ *     Marc Khouzam (Ericsson) - Added support for expression aliases for return values of functions (bug 341731)
  *******************************************************************************/
 package org.eclipse.cdt.dsf.mi.service;
 
+import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Hashtable;
+import java.util.List;
 import java.util.Map;
+import java.util.Map.Entry;
 
 import org.eclipse.cdt.core.IAddress;
 import org.eclipse.cdt.dsf.concurrent.DataRequestMonitor;
@@ -35,7 +39,11 @@ import org.eclipse.cdt.dsf.debug.service.IFormattedValues;
 import org.eclipse.cdt.dsf.debug.service.IMemory.IMemoryChangedEvent;
 import org.eclipse.cdt.dsf.debug.service.IMemory.IMemoryDMContext;
 import org.eclipse.cdt.dsf.debug.service.IRegisters.IRegisterDMContext;
-import org.eclipse.cdt.dsf.debug.service.IRunControl;
+import org.eclipse.cdt.dsf.debug.service.IRunControl.IContainerSuspendedDMEvent;
+import org.eclipse.cdt.dsf.debug.service.IRunControl.IExecutionDMContext;
+import org.eclipse.cdt.dsf.debug.service.IRunControl.IExitedDMEvent;
+import org.eclipse.cdt.dsf.debug.service.IRunControl.IResumedDMEvent;
+import org.eclipse.cdt.dsf.debug.service.IRunControl.ISuspendedDMEvent;
 import org.eclipse.cdt.dsf.debug.service.IRunControl.StateChangeReason;
 import org.eclipse.cdt.dsf.debug.service.IStack.IFrameDMContext;
 import org.eclipse.cdt.dsf.debug.service.command.CommandCache;
@@ -49,12 +57,16 @@ import org.eclipse.cdt.dsf.mi.service.command.commands.ExprMetaGetChildCount;
 import org.eclipse.cdt.dsf.mi.service.command.commands.ExprMetaGetChildren;
 import org.eclipse.cdt.dsf.mi.service.command.commands.ExprMetaGetValue;
 import org.eclipse.cdt.dsf.mi.service.command.commands.ExprMetaGetVar;
+import org.eclipse.cdt.dsf.mi.service.command.events.IMIDMEvent;
+import org.eclipse.cdt.dsf.mi.service.command.events.MIFunctionFinishedEvent;
+import org.eclipse.cdt.dsf.mi.service.command.events.MIStoppedEvent;
 import org.eclipse.cdt.dsf.mi.service.command.output.ExprMetaGetAttributesInfo;
 import org.eclipse.cdt.dsf.mi.service.command.output.ExprMetaGetChildCountInfo;
 import org.eclipse.cdt.dsf.mi.service.command.output.ExprMetaGetChildrenInfo;
 import org.eclipse.cdt.dsf.mi.service.command.output.ExprMetaGetValueInfo;
 import org.eclipse.cdt.dsf.mi.service.command.output.ExprMetaGetVarInfo;
 import org.eclipse.cdt.dsf.mi.service.command.output.MIDataEvaluateExpressionInfo;
+import org.eclipse.cdt.dsf.mi.service.command.output.MIFrame;
 import org.eclipse.cdt.dsf.service.AbstractDsfService;
 import org.eclipse.cdt.dsf.service.DsfServiceEventHandler;
 import org.eclipse.cdt.dsf.service.DsfServicesTracker;
@@ -815,6 +827,116 @@ public class MIExpressions extends AbstractDsfService implements IMIExpressions,
         }
     }
 
+    /**
+     * Keeps track of aliases for return values of methods.
+     */
+	private class ReturnValueAliasing {
+		/**
+		 *  Map of expression to alias.  The expression is the name of the convenience variable 
+		 *  storing the return value, e.g., $1 -> "foo() returned"
+		 *  This map allows to quickly find the alias to be used for return value variables. 
+		 */
+		private Map<String, String> fExpressionAliasesMap = new HashMap<String, String>();
+		/**
+		 * Map of thread to aliases expression list.  This map allows to know which aliases are related
+		 * to a thread of execution.  This is important to allow us to delete aliases when a
+		 * thread exits.  Note that we need a list because we keep all previous aliases until
+		 * the thread exits.
+		 */
+		private Map<IMIExecutionDMContext, List<String>> fThreadToAliasedExpressionsMap = new HashMap<IMIExecutionDMContext, List<String>>();
+		/**
+		 * Map of thread to the name of the method the thread last stopped in.
+		 * This allows us to create the alias based on the method the thread was in
+		 * before it returned out of the method.
+		 */
+		private Map<IMIExecutionDMContext, String> fThreadToTopMethodName = new HashMap<IMIExecutionDMContext, String>();
+		
+		/**
+		 * Create an alias for expr with respect to threadDmc.
+		 * The alias is created based on where threadDmc was previously stopped.
+		 */
+	    public void createAlias(IMIExecutionDMContext threadDmc, String expr) {
+    		String alias = expr;
+    		String methodName = fThreadToTopMethodName.get(threadDmc);
+    		if (methodName != null) {
+    			alias = String.format(Messages.MIExpressions_ReturnValueAlias, 
+    					                     methodName + "()"); //$NON-NLS-1$
+    		}
+
+    		fExpressionAliasesMap.put(expr, alias);
+    		
+    		List<String> aliasedExprList = fThreadToAliasedExpressionsMap.get(threadDmc);
+    		if (aliasedExprList == null) {
+    			aliasedExprList = new ArrayList<String>();
+    			fThreadToAliasedExpressionsMap.put(threadDmc, aliasedExprList);
+    		}
+    		aliasedExprList.add(expr);
+	    }
+	    
+	    /**
+	     * Clear all information related to a particular thread of execution.
+	     */
+	    public void clearThread(IMIExecutionDMContext threadDmc) {
+	    	fThreadToTopMethodName.remove(threadDmc);
+	    	clearAliases(threadDmc);
+	    }
+
+	    /**
+	     * Clear all aliased expressions related to a particular thread of execution.
+	     * It is good to keep the aliases around as long as the thread is alive;
+	     * even if we won't show the return value automatically, the user
+	     * could add the expression in the expression view, and the alias 
+	     * would then be used. 
+	     */
+	    public void clearAliases(IMIExecutionDMContext threadDmc) {
+	    	List<String> aliasedExprList = fThreadToAliasedExpressionsMap.remove(threadDmc);
+	    	if (aliasedExprList != null) {
+	    		for (String expr : aliasedExprList) {
+	    			fExpressionAliasesMap.remove(expr);        			
+	    		}
+	    	}
+	    }
+
+	    /**
+	     * Update the method name of the last location where threadDmc was stopped.
+	     */
+	    public void updateStoppedLocation(IMIExecutionDMContext threadDmc, String methodName) {
+	    	fThreadToTopMethodName.put(threadDmc, methodName);
+	    }
+	    
+	    /**
+	     * @return The alias for 'expr' if there is one.  null if there
+	     *         is no alias for that expression.
+	     */
+	    public String getAlias(String expr) {
+	    	String alias = fExpressionAliasesMap.get(expr);
+	    	if (alias == null) {
+	    		// Check if the expression contains the string that must be aliased.
+	    		// E.g., $1[0], *$2
+	    		// If it does, just replace that string within the expression to
+	    		// create the full alias
+	    		for (Entry<String, String> entry : fExpressionAliasesMap.entrySet()) {
+	    			int index = expr.indexOf(entry.getKey());
+	    			if (index != -1) {
+	    				// Found the string! Now replace it with our alias.
+	    				// We put it between () to make things clearer to the user.
+	    				// Note that there can only be one string contained
+	    				// in the expression, so once we found it, we are done.
+	    				alias = expr.substring(0, index) +
+	    							"(" + entry.getValue() + ")" +  //$NON-NLS-1$ //$NON-NLS-2$
+	    							expr.substring(index + entry.getKey().length());
+	    				break;
+	    			}
+	    		}
+	    	}
+	    	return alias;
+	    }
+	}
+	
+	/** Structure to keep track of aliases for method return values. */
+	private ReturnValueAliasing fReturnValueAliases = new ReturnValueAliasing();
+	
+
 	/**
 	 * @since 4.3
 	 */
@@ -1061,8 +1183,13 @@ public class MIExpressions extends AbstractDsfService implements IMIExpressions,
                             }
                         }
                         
+                        String relativeExpr = getData().getExpr();
+                        String alias = fReturnValueAliases.getAlias(relativeExpr);
+                		if (alias != null) {
+                			relativeExpr = alias;
+                		}
                         rm.setData(new ExpressionDMData(
-                            getData().getExpr(),getData().getType(), getData().getNumChildren(), 
+                            relativeExpr, getData().getType(), getData().getNumChildren(), 
                             getData().getEditable(), basicType));
                         rm.done();
                     }
@@ -1492,7 +1619,7 @@ public class MIExpressions extends AbstractDsfService implements IMIExpressions,
 	}
 
     @DsfServiceEventHandler 
-    public void eventDispatched(IRunControl.IResumedDMEvent e) {
+    public void eventDispatched(IResumedDMEvent e) {
         fExpressionCache.setContextAvailable(e.getDMContext(), false);
         if (e.getReason() != StateChangeReason.STEP) {
             fExpressionCache.reset();
@@ -1500,9 +1627,55 @@ public class MIExpressions extends AbstractDsfService implements IMIExpressions,
     }
     
     @DsfServiceEventHandler 
-    public void eventDispatched(IRunControl.ISuspendedDMEvent e) {
+    public void eventDispatched(ISuspendedDMEvent e) {
         fExpressionCache.setContextAvailable(e.getDMContext(), true);
         fExpressionCache.reset();
+        
+        handleReturnValueAliasing(e);
+    }
+    
+    private void handleReturnValueAliasing(ISuspendedDMEvent e) {
+        // Process MIStoppedEvent from within the ISuspendedDMEvent
+        // to avoid any race conditions where the actual MIStoppedEvent
+        // can arrive faster that a preceding IResumedDMEvent
+        if (e instanceof IMIDMEvent) {
+        	Object miEvent = ((IMIDMEvent)e).getMIEvent();
+        	if (miEvent instanceof MIStoppedEvent) {
+        		IMIExecutionDMContext stoppedEventThread = null;
+        		if (e instanceof IContainerSuspendedDMEvent) {
+        			// All-stop mode
+                	IExecutionDMContext[] triggerContexts = ((IContainerSuspendedDMEvent)e).getTriggeringContexts();
+                    if (triggerContexts.length != 0 && triggerContexts[0] instanceof IMIExecutionDMContext) {
+                    	stoppedEventThread = (IMIExecutionDMContext)triggerContexts[0];
+                    }
+        		} else {
+        			// Non-stop mode
+        			IDMContext dmc = e.getDMContext();
+        			if (dmc instanceof IMIExecutionDMContext) {
+        				stoppedEventThread = (IMIExecutionDMContext)dmc;
+        			}
+        		}
+        			
+        		if (stoppedEventThread != null) {
+        			if (miEvent instanceof MIFunctionFinishedEvent) {
+        				// When getting an MIFunctionFinishedEvent we must set
+        				// a proper alias for the convenience variable
+        				String resultVar = ((MIFunctionFinishedEvent)miEvent).getGDBResultVar();
+        				if (resultVar != null && !resultVar.isEmpty()) {
+        					fReturnValueAliases.createAlias(stoppedEventThread, resultVar);
+        				}
+        			}
+
+        			// Keep track of the latest method the thread is stopped in.
+        			// Must do this after creating any alias, or else we will overwrite
+        			// the previous function name, which we need for the alias
+        			MIFrame frame = ((MIStoppedEvent)miEvent).getFrame();
+        			if (frame != null) {
+        				fReturnValueAliases.updateStoppedLocation(stoppedEventThread, frame.getFunction());
+        			}
+        		}
+        	}
+        }
     }
 
     @DsfServiceEventHandler 
@@ -1520,6 +1693,20 @@ public class MIExpressions extends AbstractDsfService implements IMIExpressions,
     		fTraceVisualization = false;
     	}
     }
+
+    /**
+     * @nooverride This method is not intended to be re-implemented or extended by clients.
+     * @noreference This method is not intended to be referenced by clients.
+     */
+    @DsfServiceEventHandler 
+    public void eventDispatched(IExitedDMEvent e) {
+    	IDMContext ctx = e.getDMContext();
+    	if (ctx instanceof IMIExecutionDMContext) {
+    		// When a thread exits, clear the alias structure for that
+    		// thread to avoid leaks
+    		fReturnValueAliases.clearThread((IMIExecutionDMContext)ctx);
+    	}
+    }
     
     /**
      * {@inheritDoc}
