@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2010 Ericsson and others.
+ * Copyright (c) 2007, 2014 Ericsson and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -31,6 +31,7 @@ import org.eclipse.cdt.dsf.service.DsfServiceEventHandler;
 import org.eclipse.cdt.dsf.service.DsfSession;
 import org.eclipse.cdt.dsf.service.DsfSession.SessionStartedListener;
 import org.eclipse.cdt.tests.dsf.gdb.launching.TestsPlugin;
+import org.eclipse.cdt.tests.dsf.gdb.tests.ITestConstants;
 import org.eclipse.cdt.utils.spawner.ProcessFactory;
 import org.eclipse.core.runtime.NullProgressMonitor;
 import org.eclipse.core.runtime.Platform;
@@ -58,7 +59,7 @@ import org.junit.rules.Timeout;
  * This is the base class for the GDB/MI Unit tests.
  * It provides the @Before and @After methods which setup
  * and teardown the launch, for each test.
- * If these methods are overwridden by a subclass, the new method
+ * If these methods are overridden by a subclass, the new method
  * must call super.baseSetup or super.baseTeardown itself, if this
  * code is to be run.
  */
@@ -67,7 +68,7 @@ public class BaseTestCase {
 	// Timeout value for each individual test
 	private final static int TEST_TIMEOUT = 5 * 60 * 1000; // 5 minutes in milliseconds
 	
-	// Make the current test naem available through testName.getMethodName()
+	// Make the current test name available through testName.getMethodName()
 	@Rule public TestName testName = new TestName();
 	
 	// Add a timeout for each test, to make sure no test hangs
@@ -84,7 +85,7 @@ public class BaseTestCase {
 	// A set of global launch attributes which are not
 	// reset when we load a new class of tests.
 	// This allows a Suite to set an attribute
-	// The suite is reponsible for clearing those attributes
+	// The suite is responsible for clearing those attributes
 	// once it is finished
 	private static Map<String, Object> globalLaunchAttributes = new HashMap<String, Object>();
 
@@ -215,7 +216,8 @@ public class BaseTestCase {
     	launchAttributes.put(IGDBLaunchConfigurationConstants.ATTR_REMOTE_TCP, true);
     	launchAttributes.put(IGDBLaunchConfigurationConstants.ATTR_HOST, "localhost");
     	launchAttributes.put(IGDBLaunchConfigurationConstants.ATTR_PORT, "9999");
-    	
+    	launchAttributes.put(ITestConstants.LAUNCH_GDB_SERVER, true);
+
     	setGdbVersion();
     	
     	// Set the global launch attributes
@@ -228,17 +230,17 @@ public class BaseTestCase {
  	protected void doLaunch() throws Exception {
  		boolean remote = launchAttributes.get(ICDTLaunchConfigurationConstants.ATTR_DEBUGGER_START_MODE).equals(IGDBLaunchConfigurationConstants.DEBUGGER_MODE_REMOTE);
  		
-    	if(GdbDebugOptions.DEBUG) GdbDebugOptions.trace("===============================================================================================\n");
-		System.out.println(String.format("%s \"%s\" launching %s %s", 
-				                         GdbPlugin.getDebugTime(), testName.getMethodName(), launchAttributes.get(IGDBLaunchConfigurationConstants.ATTR_DEBUG_NAME), remote ? "with gdbserver" : ""));
-		if(GdbDebugOptions.DEBUG) GdbDebugOptions.trace("===============================================================================================\n");
+    	if (GdbDebugOptions.DEBUG) {
+    		GdbDebugOptions.trace("===============================================================================================\n");
+    		GdbDebugOptions.trace(String.format("%s \"%s\" launching %s %s\n", 
+    				GdbPlugin.getDebugTime(), testName.getMethodName(), launchAttributes.get(IGDBLaunchConfigurationConstants.ATTR_DEBUG_NAME), remote ? "with gdbserver" : ""));
+    		GdbDebugOptions.trace("===============================================================================================\n");
+    	}
 		
  		boolean postMortemLaunch = launchAttributes.get(ICDTLaunchConfigurationConstants.ATTR_DEBUGGER_START_MODE)
 	                                               .equals(ICDTLaunchConfigurationConstants.DEBUGGER_MODE_CORE);
  		
- 		// First check if we should launch gdbserver in the case of a remote session
- 		if (reallyLaunchGDBServer())
- 			launchGdbServer();
+		launchGdbServer();
 		
  		ILaunchManager launchMgr = DebugPlugin.getDefault().getLaunchManager();
  		ILaunchConfigurationType lcType = launchMgr.getLaunchConfigurationType("org.eclipse.cdt.tests.dsf.gdb.TestLaunch");
@@ -315,6 +317,12 @@ public class BaseTestCase {
  	 * If the user specified a different host, things won't work.
  	 */
  	private void launchGdbServer() {
+ 		// First check if we should not launch gdbserver even for a remote session
+ 		if (launchAttributes.get(ITestConstants.LAUNCH_GDB_SERVER).equals(false)) {
+ 			if (GdbDebugOptions.DEBUG) GdbDebugOptions.trace("Forcing to not start gdbserver for this test\n");
+ 			return;
+ 		}
+
  		if (launchAttributes.get(ICDTLaunchConfigurationConstants.ATTR_DEBUGGER_START_MODE)
  				              .equals(IGDBLaunchConfigurationConstants.DEBUGGER_MODE_REMOTE)) {
  			if (launchAttributes.get(IGDBLaunchConfigurationConstants.ATTR_REMOTE_TCP).equals(Boolean.TRUE)) {
@@ -323,7 +331,7 @@ public class BaseTestCase {
  				String program = (String)launchAttributes.get(ICDTLaunchConfigurationConstants.ATTR_PROGRAM_NAME);
  				String commandLine = server + " :" + port + " " + program;
  				try {
-                    System.out.println("Staring gdbserver with command: " + commandLine);
+ 					if (GdbDebugOptions.DEBUG) GdbDebugOptions.trace("Starting gdbserver with command: " + commandLine + "\n");
 
  					gdbserverProc = ProcessFactory.getFactory().exec(commandLine);
                     Reader r = new InputStreamReader(gdbserverProc.getErrorStream());
@@ -337,7 +345,7 @@ public class BaseTestCase {
                         }
                     }
  				} catch (Exception e) {
- 					System.out.println("Error while launching command: " + commandLine);
+ 					GdbDebugOptions.trace("Error while launching command: " + commandLine + "\n");
  					e.printStackTrace();
  					assert false;
  				} 				
@@ -391,16 +399,6 @@ public class BaseTestCase {
         	Assume.assumeNoException(e);
         }
  	}
- 	
- 	/**
- 	 * In some tests we need to start a gdbserver session without starting gdbserver. 
- 	 * This method allows super classes of this class control the launch of gdbserver.
- 	 * 
- 	 * @return whether gdbserver should be started
- 	 */
- 	protected boolean reallyLaunchGDBServer() {
- 		return true;
- 	}
 
 	@BeforeClass
  	public static void setGlobalPreferences() {
