@@ -11,6 +11,8 @@
  *******************************************************************************/
 package org.eclipse.cdt.tests.dsf.gdb.tests;
 
+import org.eclipse.cdt.tests.dsf.gdb.launching.TestsPlugin;
+
 public interface ITestConstants {
 
 	public static final String SUFFIX_GDB_6_6 = "6.6";
@@ -25,4 +27,7 @@ public interface ITestConstants {
 	public static final String SUFFIX_GDB_7_6 = "7.6";
 	public static final String SUFFIX_GDB_7_7 = "7.7";
 	public static final String SUFFIX_GDB_7_8 = "7.8";
+	
+	// Attribute that allows a test to request not to start gdbserver even if the session is a remote one
+	public static final String LAUNCH_GDB_SERVER = TestsPlugin.PLUGIN_ID + ".launchGdbServer";
 }
