@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2011 Ericsson and others.
+ * Copyright (c) 2009, 2014 Ericsson and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -7,10 +7,10 @@
  * 
  * Contributors:
  *     Ericsson			  - Initial Implementation
+ *     Alvaro Sanchez-Leon (Ericsson) - Bug 437562 - Split the dsf-gdb tests to a plug-in and fragment pair
  *******************************************************************************/
-package org.eclipse.cdt.tests.dsf.gdb.tests.tests_7_3;
+package org.eclipse.cdt.tests.dsf.gdb.tests.tests_7_0;
 
-import org.eclipse.cdt.dsf.mi.service.command.commands.Suite_Sessionless_Tests;
 import org.eclipse.cdt.tests.dsf.gdb.framework.BaseRemoteSuite;
 import org.eclipse.cdt.tests.dsf.gdb.framework.BaseTestCase;
 import org.eclipse.cdt.tests.dsf.gdb.tests.ITestConstants;
@@ -24,38 +24,37 @@ import org.junit.runners.Suite;
  * want to run.  When creating a new test class, it should be
  * added to the list below.
  * 
- *  This suite is for tests to be run with GDB 7.3
+ *  This suite is for tests to be run with GDB 7.0
  */
 
 @RunWith(Suite.class)
 @Suite.SuiteClasses({
 	// We need specific name for the tests of this suite, because of bug https://bugs.eclipse.org/172256
-	GDBRemoteTracepointsTest_7_3.class,
-	MIRegistersTest_7_3.class,
-	MIRunControlTest_7_3.class,
-	MIRunControlTargetAvailableTest_7_3.class,
-	MIRunControlNonStopTargetAvailableTest_7_3.class,
-	MIExpressionsTest_7_3.class,
-	GDBPatternMatchingExpressionsTest_7_3.class,
-	MIMemoryTest_7_3.class,
-	MIBreakpointsTest_7_3.class,
-	MICatchpointsTest_7_3.class,
-	MIDisassemblyTest_7_3.class,
-	GDBProcessesTest_7_3.class,
-	OperationsWhileTargetIsRunningTest_7_3.class,
-	OperationsWhileTargetIsRunningNonStopTest_7_3.class,
-	CommandTimeoutTest_7_3.class,
-	GDBMultiNonStopRunControlTest_7_3.class,
-	Suite_Sessionless_Tests.class,
-	StepIntoSelectionTest_7_3.class,
-	StepIntoSelectionNonStopTest_7_3.class,
+	GDBRemoteTracepointsTest_7_0.class,
+	MIRegistersTest_7_0.class,
+	MIRunControlTargetAvailableTest_7_0.class,
+	MIRunControlNonStopTargetAvailableTest_7_0.class,
+	MIRunControlTest_7_0.class,
+	MIExpressionsTest_7_0.class,
+	GDBPatternMatchingExpressionsTest_7_0.class,
+	MIMemoryTest_7_0.class,
+	MIBreakpointsTest_7_0.class,
+	MICatchpointsTest_7_0.class,
+	MIDisassemblyTest_7_0.class,
+	GDBProcessesTest_7_0.class,
+	OperationsWhileTargetIsRunningTest_7_0.class,
+	OperationsWhileTargetIsRunningNonStopTest_7_0.class,
+	CommandTimeoutTest_7_0.class,
+	GDBMultiNonStopRunControlTest_7_0.class,
+	StepIntoSelectionTest_7_0.class,
+	StepIntoSelectionNonStopTest_7_0.class,
 	/* Add your test class here */
 })
 
-public class Suite_Remote_7_3 extends BaseRemoteSuite {
+public class Suite_Remote_7_0 extends BaseRemoteSuite {
 	@BeforeClass
 	public static void beforeClassMethod() {
-		BaseTestCase.setGdbProgramNamesLaunchAttributes(ITestConstants.SUFFIX_GDB_7_3);
+		BaseTestCase.setGdbProgramNamesLaunchAttributes(ITestConstants.SUFFIX_GDB_7_0);
 		BaseTestCase.ignoreIfGDBMissing();
 	}
 }
