@@ -1,25 +1,25 @@
 /*******************************************************************************
- * Copyright (c) 2011 Ericsson and others.
+ * Copyright (c) 2014 Ericsson and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  * 
  * Contributors:
- *     Ericsson	AB		  - Initial implementation of Test cases
+ *     Marc Khouzam (Ericsson) - Initial implementation of Test cases
  *******************************************************************************/
-package org.eclipse.cdt.tests.dsf.gdb.tests.tests_6_6;
+package org.eclipse.cdt.tests.dsf.gdb.tests.tests_7_7;
 
 
 import org.eclipse.cdt.tests.dsf.gdb.framework.BackgroundRunner;
 import org.eclipse.cdt.tests.dsf.gdb.tests.ITestConstants;
-import org.eclipse.cdt.tests.dsf.gdb.tests.OperationsWhileTargetIsRunningTest;
+import org.eclipse.cdt.tests.dsf.gdb.tests.tests_7_6.OperationsWhileTargetIsRunningTest_7_6;
 import org.junit.runner.RunWith;
 
 @RunWith(BackgroundRunner.class)
-public class OperationsWhileTargetIsRunningTest_6_6 extends OperationsWhileTargetIsRunningTest {
+public class OperationsWhileTargetIsRunningTest_7_7 extends OperationsWhileTargetIsRunningTest_7_6 {
     @Override
 	protected void setGdbVersion() {
-		setGdbProgramNamesLaunchAttributes(ITestConstants.SUFFIX_GDB_6_6);
+		setGdbProgramNamesLaunchAttributes(ITestConstants.SUFFIX_GDB_7_7);
 	}
 }
